
# Slot: quantity




URI: [nwb_schema_language:quantity](https://w3id.org/p2p_ld/nwb-schema-language/quantity)


## Domain and Range

None &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [Dataset](Dataset.md)
 * [Group](Group.md)
 * [Link](Link.md)
